@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: LOCAL.pm,v 1.1.1.1 2002/11/01 14:53:56 paulclinger Exp $
+# $Id: LOCAL.pm,v 1.3 2004/11/14 19:30:50 byrnereese Exp $
 #
 # ======================================================================
 
@@ -12,7 +12,8 @@ package SOAP::Transport::LOCAL;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_60-public $ =~ /-(\d+)_([\d_]+)/);
+#$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name:  $ =~ /-(\d+)_([\d_]+)/);
+$VERSION = $SOAP::Lite::VERSION;
 
 # ======================================================================
 
@@ -55,24 +56,3 @@ sub send_receive {
 1;
 
 __END__
-
-=head1 NAME
-
-SOAP::Transport::LOCAL - Client side no-transport support for SOAP::Lite
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 COPYRIGHT
-
-Copyright (C) 2000-2001 Paul Kulchenko. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Paul Kulchenko (paulclinger@yahoo.com)
-
-=cut
