@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: TCP.pm,v 1.1.1.1 2002/11/01 14:53:56 paulclinger Exp $
+# $Id: TCP.pm,v 1.4 2004/11/14 19:30:50 byrnereese Exp $
 #
 # ======================================================================
 
@@ -12,7 +12,8 @@ package SOAP::Transport::TCP;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name: release-0_60-public $ =~ /-(\d+)_([\d_]+)/);
+#$VERSION = sprintf("%d.%s", map {s/_//g; $_} q$Name:  $ =~ /-(\d+)_([\d_]+)/);
+$VERSION = $SOAP::Lite::VERSION;
 
 use URI;
 use IO::Socket;
@@ -222,34 +223,3 @@ sub handle {
 1;
 
 __END__
-
-=head1 NAME
-
-SOAP::Transport::TCP - Server/Client side TCP support for SOAP::Lite
-
-=head1 SYNOPSIS
-
-  use SOAP::Transport::TCP;
-
-  my $daemon = SOAP::Transport::TCP::Server
-    -> new (LocalAddr => 'localhost', LocalPort => 82, Listen => 5, Reuse => 1)
-    -> objects_by_reference(qw(My::PersistentIterator My::SessionIterator My::Chat))
-    -> dispatch_to('/Your/Path/To/Deployed/Modules', 'Module::Name', 'Module::method') 
-  ;
-  print "Contact to SOAP server at ", join(':', $daemon->sockhost, $daemon->sockport), "\n";
-  $daemon->handle;
-
-=head1 DESCRIPTION
-
-=head1 COPYRIGHT
-
-Copyright (C) 2000-2001 Paul Kulchenko. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Paul Kulchenko (paulclinger@yahoo.com)
-
-=cut
